# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.messages_api import MessagesApi  # noqa: E501
from swagger_client.rest import ApiException


class TestMessagesApi(unittest.TestCase):
    """MessagesApi unit test stubs"""

    def setUp(self):
        self.api = MessagesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_message(self):
        """Test case for get_message

        Gets a single specific message by its internal id  # noqa: E501
        """
        pass

    def test_get_message_by_external_id(self):
        """Test case for get_message_by_external_id

        Gets a single specific message by its external id  # noqa: E501
        """
        pass

    def test_get_message_history(self):
        """Test case for get_message_history

        Gets historial messages in bulk  # noqa: E501
        """
        pass

    def test_send_file_to_customer(self):
        """Test case for send_file_to_customer

        Sends a file and an optional message to a customer, creating the customer, customer channel and conversation if needed.  # noqa: E501
        """
        pass

    def test_send_to_customer(self):
        """Test case for send_to_customer

        Sends a message and an optional instant app to a customer using API Ids, creating the customer, customer channel and conversation if needed.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
