# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.tags_api import TagsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_tag(self):
        """Test case for add_tag

        Creates a tag  # noqa: E501
        """
        pass

    def test_delete_tag(self):
        """Test case for delete_tag

        Deletes the tag  # noqa: E501
        """
        pass

    def test_get_customer_tags1(self):
        """Test case for get_customer_tags1

        Gets the customers for a specific tag  # noqa: E501
        """
        pass

    def test_get_tags(self):
        """Test case for get_tags

        Gets all tags  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
