# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.groups_api import GroupsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self):
        self.api = GroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_group(self):
        """Test case for add_group

        Creates a group  # noqa: E501
        """
        pass

    def test_delete_group(self):
        """Test case for delete_group

        Deletes a group  # noqa: E501
        """
        pass

    def test_get_group(self):
        """Test case for get_group

        Gets the details of a specific group  # noqa: E501
        """
        pass

    def test_get_groups(self):
        """Test case for get_groups

        Gets all the groups in the org  # noqa: E501
        """
        pass

    def test_get_org_channel_permission(self):
        """Test case for get_org_channel_permission

        Gets a group's's orgChannel permission  # noqa: E501
        """
        pass

    def test_get_org_channel_permissions(self):
        """Test case for get_org_channel_permissions

        Gets a group's's orgChannel permissions  # noqa: E501
        """
        pass

    def test_get_permission(self):
        """Test case for get_permission

        Gets a group's permission  # noqa: E501
        """
        pass

    def test_get_permissions(self):
        """Test case for get_permissions

        Gets a group's permissions  # noqa: E501
        """
        pass

    def test_set_org_channel_permissions(self):
        """Test case for set_org_channel_permissions

        Sets a group's orgChannel permissions  # noqa: E501
        """
        pass

    def test_set_permissions(self):
        """Test case for set_permissions

        Sets a group's permissions  # noqa: E501
        """
        pass

    def test_update_group(self):
        """Test case for update_group

        Modifies a group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
