# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.maps_api import MapsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestMapsApi(unittest.TestCase):
    """MapsApi unit test stubs"""

    def setUp(self):
        self.api = MapsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_customer_to_map(self):
        """Test case for add_customer_to_map

        Adds a customer location to a map  # noqa: E501
        """
        pass

    def test_add_google_map(self):
        """Test case for add_google_map

        Creates a map  # noqa: E501
        """
        pass

    def test_delete_google_map(self):
        """Test case for delete_google_map

        Deletes a map  # noqa: E501
        """
        pass

    def test_get_google_map(self):
        """Test case for get_google_map

        Gets a map  # noqa: E501
        """
        pass

    def test_remove_customer_from_map(self):
        """Test case for remove_customer_from_map

        Removes a customer location from a map  # noqa: E501
        """
        pass

    def test_update_google_map(self):
        """Test case for update_google_map

        Update a map  # noqa: E501
        """
        pass

    def test_update_google_map_icons(self):
        """Test case for update_google_map_icons

        Update a map's icons  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
