# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PostMessageModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'team_member_id': 'int',
        'content': 'str',
        'ignore_delivery_restrictions': 'bool'
    }

    attribute_map = {
        'team_member_id': 'teamMemberId',
        'content': 'content',
        'ignore_delivery_restrictions': 'ignoreDeliveryRestrictions'
    }

    def __init__(self, team_member_id=None, content=None, ignore_delivery_restrictions=None):  # noqa: E501
        """PostMessageModel - a model defined in Swagger"""  # noqa: E501
        self._team_member_id = None
        self._content = None
        self._ignore_delivery_restrictions = None
        self.discriminator = None
        self.team_member_id = team_member_id
        self.content = content
        if ignore_delivery_restrictions is not None:
            self.ignore_delivery_restrictions = ignore_delivery_restrictions

    @property
    def team_member_id(self):
        """Gets the team_member_id of this PostMessageModel.  # noqa: E501

        ID of the team member.  # noqa: E501

        :return: The team_member_id of this PostMessageModel.  # noqa: E501
        :rtype: int
        """
        return self._team_member_id

    @team_member_id.setter
    def team_member_id(self, team_member_id):
        """Sets the team_member_id of this PostMessageModel.

        ID of the team member.  # noqa: E501

        :param team_member_id: The team_member_id of this PostMessageModel.  # noqa: E501
        :type: int
        """
        if team_member_id is None:
            raise ValueError("Invalid value for `team_member_id`, must not be `None`")  # noqa: E501

        self._team_member_id = team_member_id

    @property
    def content(self):
        """Gets the content of this PostMessageModel.  # noqa: E501

        The content of the message  # noqa: E501

        :return: The content of this PostMessageModel.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this PostMessageModel.

        The content of the message  # noqa: E501

        :param content: The content of this PostMessageModel.  # noqa: E501
        :type: str
        """
        if content is None:
            raise ValueError("Invalid value for `content`, must not be `None`")  # noqa: E501

        self._content = content

    @property
    def ignore_delivery_restrictions(self):
        """Gets the ignore_delivery_restrictions of this PostMessageModel.  # noqa: E501

        Whether the message should be sent immediately, ignoring any message delivery time restrictions that have been configured. Default is false.  # noqa: E501

        :return: The ignore_delivery_restrictions of this PostMessageModel.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_delivery_restrictions

    @ignore_delivery_restrictions.setter
    def ignore_delivery_restrictions(self, ignore_delivery_restrictions):
        """Sets the ignore_delivery_restrictions of this PostMessageModel.

        Whether the message should be sent immediately, ignoring any message delivery time restrictions that have been configured. Default is false.  # noqa: E501

        :param ignore_delivery_restrictions: The ignore_delivery_restrictions of this PostMessageModel.  # noqa: E501
        :type: bool
        """

        self._ignore_delivery_restrictions = ignore_delivery_restrictions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PostMessageModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PostMessageModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
