# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.pools_api import PoolsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestPoolsApi(unittest.TestCase):
    """PoolsApi unit test stubs"""

    def setUp(self):
        self.api = PoolsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_pool(self):
        """Test case for add_pool

        Creates a pool  # noqa: E501
        """
        pass

    def test_delete_pool(self):
        """Test case for delete_pool

        Deletes a pool  # noqa: E501
        """
        pass

    def test_get_available_numbers(self):
        """Test case for get_available_numbers

        Gets phone numbers that are available to be purchased from the given provider  # noqa: E501
        """
        pass

    def test_get_pool(self):
        """Test case for get_pool

        Gets a specific pool  # noqa: E501
        """
        pass

    def test_get_pools(self):
        """Test case for get_pools

        Gets all pools  # noqa: E501
        """
        pass

    def test_update_pool(self):
        """Test case for update_pool

        Updates a pool  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
