# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.scheduled_actions_api import ScheduledActionsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestScheduledActionsApi(unittest.TestCase):
    """ScheduledActionsApi unit test stubs"""

    def setUp(self):
        self.api = ScheduledActionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_scheduled_action(self):
        """Test case for abort_scheduled_action

        Abort a Scheduled Action  # noqa: E501
        """
        pass

    def test_add_scheduled_action(self):
        """Test case for add_scheduled_action

        Creates a Scheduled Action  # noqa: E501
        """
        pass

    def test_get_pending_scheduled_actions(self):
        """Test case for get_pending_scheduled_actions

        Gets pending Scheduled Actions  # noqa: E501
        """
        pass

    def test_get_scheduled_action(self):
        """Test case for get_scheduled_action

        Gets a specific Scheduled Action  # noqa: E501
        """
        pass

    def test_get_scheduled_actions(self):
        """Test case for get_scheduled_actions

        Gets all Scheduled Actions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
