# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.contact_lists_api import ContactListsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestContactListsApi(unittest.TestCase):
    """ContactListsApi unit test stubs"""

    def setUp(self):
        self.api = ContactListsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_contact_list(self):
        """Test case for add_contact_list

        Creates a Contact List  # noqa: E501
        """
        pass

    def test_delete_contact_list(self):
        """Test case for delete_contact_list

        Deletes a Contact List  # noqa: E501
        """
        pass

    def test_get_contact_list(self):
        """Test case for get_contact_list

        Gets a specific Contact List  # noqa: E501
        """
        pass

    def test_get_contact_lists(self):
        """Test case for get_contact_lists

        Gets all Contact Lists  # noqa: E501
        """
        pass

    def test_perform_action1(self):
        """Test case for perform_action1

        Performs an action on the contacts in a Contact List  # noqa: E501
        """
        pass

    def test_update_contact_list(self):
        """Test case for update_contact_list

        Modifies a Contact List  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
