# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ZipwhipOrgChannelModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'phone_number': 'str',
        'fast_bulk_send': 'bool',
        'approved_by': 'str',
        'user_id': 'int'
    }

    attribute_map = {
        'phone_number': 'phoneNumber',
        'fast_bulk_send': 'fastBulkSend',
        'approved_by': 'approvedBy',
        'user_id': 'userId'
    }

    def __init__(self, phone_number=None, fast_bulk_send=None, approved_by=None, user_id=None):  # noqa: E501
        """ZipwhipOrgChannelModel - a model defined in Swagger"""  # noqa: E501
        self._phone_number = None
        self._fast_bulk_send = None
        self._approved_by = None
        self._user_id = None
        self.discriminator = None
        if phone_number is not None:
            self.phone_number = phone_number
        if fast_bulk_send is not None:
            self.fast_bulk_send = fast_bulk_send
        if approved_by is not None:
            self.approved_by = approved_by
        if user_id is not None:
            self.user_id = user_id

    @property
    def phone_number(self):
        """Gets the phone_number of this ZipwhipOrgChannelModel.  # noqa: E501

        The outgoing phone number for this Zipwhip org channel  # noqa: E501

        :return: The phone_number of this ZipwhipOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this ZipwhipOrgChannelModel.

        The outgoing phone number for this Zipwhip org channel  # noqa: E501

        :param phone_number: The phone_number of this ZipwhipOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def fast_bulk_send(self):
        """Gets the fast_bulk_send of this ZipwhipOrgChannelModel.  # noqa: E501

        Enable Fast Bulk Send  # noqa: E501

        :return: The fast_bulk_send of this ZipwhipOrgChannelModel.  # noqa: E501
        :rtype: bool
        """
        return self._fast_bulk_send

    @fast_bulk_send.setter
    def fast_bulk_send(self, fast_bulk_send):
        """Sets the fast_bulk_send of this ZipwhipOrgChannelModel.

        Enable Fast Bulk Send  # noqa: E501

        :param fast_bulk_send: The fast_bulk_send of this ZipwhipOrgChannelModel.  # noqa: E501
        :type: bool
        """

        self._fast_bulk_send = fast_bulk_send

    @property
    def approved_by(self):
        """Gets the approved_by of this ZipwhipOrgChannelModel.  # noqa: E501

        Person approved the Zhipwhip org channel  # noqa: E501

        :return: The approved_by of this ZipwhipOrgChannelModel.  # noqa: E501
        :rtype: str
        """
        return self._approved_by

    @approved_by.setter
    def approved_by(self, approved_by):
        """Sets the approved_by of this ZipwhipOrgChannelModel.

        Person approved the Zhipwhip org channel  # noqa: E501

        :param approved_by: The approved_by of this ZipwhipOrgChannelModel.  # noqa: E501
        :type: str
        """

        self._approved_by = approved_by

    @property
    def user_id(self):
        """Gets the user_id of this ZipwhipOrgChannelModel.  # noqa: E501

        The user id make this request  # noqa: E501

        :return: The user_id of this ZipwhipOrgChannelModel.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ZipwhipOrgChannelModel.

        The user id make this request  # noqa: E501

        :param user_id: The user_id of this ZipwhipOrgChannelModel.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ZipwhipOrgChannelModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ZipwhipOrgChannelModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
