# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.conversations_api import ConversationsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestConversationsApi(unittest.TestCase):
    """ConversationsApi unit test stubs"""

    def setUp(self):
        self.api = ConversationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_conversation(self):
        """Test case for add_conversation

        Creates a conversation with customer and the team member  # noqa: E501
        """
        pass

    def test_assign(self):
        """Test case for assign

        Takes a conversation and assigns it to one or more groups/users  # noqa: E501
        """
        pass

    def test_assign_bot(self):
        """Test case for assign_bot

        Takes a conversation and assigns it to a bot  # noqa: E501
        """
        pass

    def test_close(self):
        """Test case for close

        Closes the requested conversation  # noqa: E501
        """
        pass

    def test_escalate(self):
        """Test case for escalate

        Takes an active conversation handled by a bot, and escalates it to groups or teamMembers  # noqa: E501
        """
        pass

    def test_get_active(self):
        """Test case for get_active

        Gets all the active conversations for a team member  # noqa: E501
        """
        pass

    def test_get_active_for_bot(self):
        """Test case for get_active_for_bot

        Gets all the active conversations for a bot  # noqa: E501
        """
        pass

    def test_get_active_for_customer(self):
        """Test case for get_active_for_customer

        Gets all the active conversations for a customer  # noqa: E501
        """
        pass

    def test_get_active_for_customer_by_channel_id(self):
        """Test case for get_active_for_customer_by_channel_id

        Gets all the active conversations for a customer  # noqa: E501
        """
        pass

    def test_get_active_for_customer_by_channel_key(self):
        """Test case for get_active_for_customer_by_channel_key

        Gets all the active conversations for a customer  # noqa: E501
        """
        pass

    def test_get_conversation(self):
        """Test case for get_conversation

        Gets a conversation based on its internal id.  # noqa: E501
        """
        pass

    def test_get_conversation_messages(self):
        """Test case for get_conversation_messages

        Gets messages for a conversation  # noqa: E501
        """
        pass

    def test_get_for_customer(self):
        """Test case for get_for_customer

        Gets all messages for a customer, as visible by a team member  # noqa: E501
        """
        pass

    def test_get_inbox(self):
        """Test case for get_inbox

        Gets all the conversations in the team members inbox.  # noqa: E501
        """
        pass

    def test_get_smart_link(self):
        """Test case for get_smart_link

        Creates a smart link for the customer involved in the conversation  # noqa: E501
        """
        pass

    def test_opt_out(self):
        """Test case for opt_out

        Opted out customers can not receive any additional messages from this conversations until opted back in  # noqa: E501
        """
        pass

    def test_post_message(self):
        """Test case for post_message

        Posts a message to an active conversation  # noqa: E501
        """
        pass

    def test_post_whisper(self):
        """Test case for post_whisper

        Posts a whisper to an active conversation  # noqa: E501
        """
        pass

    def test_remove_team_member_from_conversation(self):
        """Test case for remove_team_member_from_conversation

        Removes a team member from a conversation.  # noqa: E501
        """
        pass

    def test_take(self):
        """Test case for take

        Takes a pending conversation and moves it into an active state, ready for communication  # noqa: E501
        """
        pass

    def test_update_membership(self):
        """Test case for update_membership

        Updates the team members presences in conversation, optionally add it to their Inbox, Active Chats, or removing it altogether  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
