# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MessageModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'created_timestamp': 'int',
        'external_message_id': 'str',
        'user_id': 'int',
        'content': 'str',
        'instant_app': 'InstantAppModel',
        'uploads': 'list[UploadModel]',
        'status': 'str',
        'pool_subchannel_id': 'int'
    }

    attribute_map = {
        'id': 'id',
        'created_timestamp': 'createdTimestamp',
        'external_message_id': 'externalMessageId',
        'user_id': 'userId',
        'content': 'content',
        'instant_app': 'instantApp',
        'uploads': 'uploads',
        'status': 'status',
        'pool_subchannel_id': 'poolSubchannelId'
    }

    def __init__(self, id=None, created_timestamp=None, external_message_id=None, user_id=None, content=None, instant_app=None, uploads=None, status=None, pool_subchannel_id=None):  # noqa: E501
        """MessageModel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._created_timestamp = None
        self._external_message_id = None
        self._user_id = None
        self._content = None
        self._instant_app = None
        self._uploads = None
        self._status = None
        self._pool_subchannel_id = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if created_timestamp is not None:
            self.created_timestamp = created_timestamp
        if external_message_id is not None:
            self.external_message_id = external_message_id
        if user_id is not None:
            self.user_id = user_id
        if content is not None:
            self.content = content
        if instant_app is not None:
            self.instant_app = instant_app
        if uploads is not None:
            self.uploads = uploads
        if status is not None:
            self.status = status
        if pool_subchannel_id is not None:
            self.pool_subchannel_id = pool_subchannel_id

    @property
    def id(self):
        """Gets the id of this MessageModel.  # noqa: E501


        :return: The id of this MessageModel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MessageModel.


        :param id: The id of this MessageModel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def created_timestamp(self):
        """Gets the created_timestamp of this MessageModel.  # noqa: E501


        :return: The created_timestamp of this MessageModel.  # noqa: E501
        :rtype: int
        """
        return self._created_timestamp

    @created_timestamp.setter
    def created_timestamp(self, created_timestamp):
        """Sets the created_timestamp of this MessageModel.


        :param created_timestamp: The created_timestamp of this MessageModel.  # noqa: E501
        :type: int
        """

        self._created_timestamp = created_timestamp

    @property
    def external_message_id(self):
        """Gets the external_message_id of this MessageModel.  # noqa: E501


        :return: The external_message_id of this MessageModel.  # noqa: E501
        :rtype: str
        """
        return self._external_message_id

    @external_message_id.setter
    def external_message_id(self, external_message_id):
        """Sets the external_message_id of this MessageModel.


        :param external_message_id: The external_message_id of this MessageModel.  # noqa: E501
        :type: str
        """

        self._external_message_id = external_message_id

    @property
    def user_id(self):
        """Gets the user_id of this MessageModel.  # noqa: E501


        :return: The user_id of this MessageModel.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this MessageModel.


        :param user_id: The user_id of this MessageModel.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def content(self):
        """Gets the content of this MessageModel.  # noqa: E501


        :return: The content of this MessageModel.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this MessageModel.


        :param content: The content of this MessageModel.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def instant_app(self):
        """Gets the instant_app of this MessageModel.  # noqa: E501


        :return: The instant_app of this MessageModel.  # noqa: E501
        :rtype: InstantAppModel
        """
        return self._instant_app

    @instant_app.setter
    def instant_app(self, instant_app):
        """Sets the instant_app of this MessageModel.


        :param instant_app: The instant_app of this MessageModel.  # noqa: E501
        :type: InstantAppModel
        """

        self._instant_app = instant_app

    @property
    def uploads(self):
        """Gets the uploads of this MessageModel.  # noqa: E501


        :return: The uploads of this MessageModel.  # noqa: E501
        :rtype: list[UploadModel]
        """
        return self._uploads

    @uploads.setter
    def uploads(self, uploads):
        """Sets the uploads of this MessageModel.


        :param uploads: The uploads of this MessageModel.  # noqa: E501
        :type: list[UploadModel]
        """

        self._uploads = uploads

    @property
    def status(self):
        """Gets the status of this MessageModel.  # noqa: E501


        :return: The status of this MessageModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this MessageModel.


        :param status: The status of this MessageModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["NA", "SENT", "DELIVERED", "READ", "FAILED", "UNDELIVERED", "RECEIVED", "QUEUED", "OPTED_OUT", "ABORTED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def pool_subchannel_id(self):
        """Gets the pool_subchannel_id of this MessageModel.  # noqa: E501


        :return: The pool_subchannel_id of this MessageModel.  # noqa: E501
        :rtype: int
        """
        return self._pool_subchannel_id

    @pool_subchannel_id.setter
    def pool_subchannel_id(self, pool_subchannel_id):
        """Sets the pool_subchannel_id of this MessageModel.


        :param pool_subchannel_id: The pool_subchannel_id of this MessageModel.  # noqa: E501
        :type: int
        """

        self._pool_subchannel_id = pool_subchannel_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessageModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
