# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.customers_api import CustomersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestCustomersApi(unittest.TestCase):
    """CustomersApi unit test stubs"""

    def setUp(self):
        self.api = CustomersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_customer(self):
        """Test case for add_customer

        Creates a customer  # noqa: E501
        """
        pass

    def test_add_customer_tags(self):
        """Test case for add_customer_tags

        Adds tags to a customer  # noqa: E501
        """
        pass

    def test_add_identity(self):
        """Test case for add_identity

        Adds an identity to a customer  # noqa: E501
        """
        pass

    def test_add_or_update_customer(self):
        """Test case for add_or_update_customer

        Creates or updates a customer  # noqa: E501
        """
        pass

    def test_create_instant_app(self):
        """Test case for create_instant_app

        Creates an Instant App for the customer.  # noqa: E501
        """
        pass

    def test_delete_identity(self):
        """Test case for delete_identity

        Deletes an identity from a customer  # noqa: E501
        """
        pass

    def test_get_customer(self):
        """Test case for get_customer

        Gets the details for a specific customer  # noqa: E501
        """
        pass

    def test_get_customer_by_channel(self):
        """Test case for get_customer_by_channel

        Gets the details for a specific customer based on an the channel type and channel key  # noqa: E501
        """
        pass

    def test_get_customer_by_identity(self):
        """Test case for get_customer_by_identity

        Gets the details for a specific customer based on an identity  # noqa: E501
        """
        pass

    def test_get_customer_tags(self):
        """Test case for get_customer_tags

        Gets the tags for a specific customer  # noqa: E501
        """
        pass

    def test_get_customers(self):
        """Test case for get_customers

        Gets all the customers in the org ordered by their create date  # noqa: E501
        """
        pass

    def test_get_instant_apps(self):
        """Test case for get_instant_apps

        Gets all the Instant Apps for the customer  # noqa: E501
        """
        pass

    def test_remove_tag(self):
        """Test case for remove_tag

        Removes a tag from a customer  # noqa: E501
        """
        pass

    def test_remove_tags(self):
        """Test case for remove_tags

        Removes all tags from a customer  # noqa: E501
        """
        pass

    def test_update_customer(self):
        """Test case for update_customer

        Updates a customer  # noqa: E501
        """
        pass

    def test_update_customer_location(self):
        """Test case for update_customer_location

        Updates a customers location  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
