# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.bots_api import BotsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestBotsApi(unittest.TestCase):
    """BotsApi unit test stubs"""

    def setUp(self):
        self.api = BotsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_bot(self):
        """Test case for create_bot

        Creates a new bot  # noqa: E501
        """
        pass

    def test_delete_bot(self):
        """Test case for delete_bot

        Deletes a bot  # noqa: E501
        """
        pass

    def test_get_bot(self):
        """Test case for get_bot

        Gets a bot  # noqa: E501
        """
        pass

    def test_get_bot_intents(self):
        """Test case for get_bot_intents

        Gets all intents of a bot  # noqa: E501
        """
        pass

    def test_get_bots(self):
        """Test case for get_bots

        Gets all bots for the org.  # noqa: E501
        """
        pass

    def test_update_bot(self):
        """Test case for update_bot

        Updates an existing bot  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
