# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.api_keys_api import APIKeysApi  # noqa: E501
from swagger_client.rest import ApiException


class TestAPIKeysApi(unittest.TestCase):
    """APIKeysApi unit test stubs"""

    def setUp(self):
        self.api = APIKeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_api_key(self):
        """Test case for add_api_key

        Creates an API Key for an org  # noqa: E501
        """
        pass

    def test_delete_api_key(self):
        """Test case for delete_api_key

        Deletes an API Key for an org  # noqa: E501
        """
        pass

    def test_get_api_key(self):
        """Test case for get_api_key

        Gets a specific API Key for an org  # noqa: E501
        """
        pass

    def test_get_api_keys(self):
        """Test case for get_api_keys

        Gets all API Keys for an org  # noqa: E501
        """
        pass

    def test_reset_token(self):
        """Test case for reset_token

        Resets the secret for an API Key  # noqa: E501
        """
        pass

    def test_update_api_key(self):
        """Test case for update_api_key

        Updates an API Key for an org  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
