# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.tag_groups_api import TagGroupsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestTagGroupsApi(unittest.TestCase):
    """TagGroupsApi unit test stubs"""

    def setUp(self):
        self.api = TagGroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_tag_group(self):
        """Test case for add_tag_group

        Creates a tag group  # noqa: E501
        """
        pass

    def test_add_tag_to_tag_group(self):
        """Test case for add_tag_to_tag_group

        Add a tag to a tag group  # noqa: E501
        """
        pass

    def test_delete_tag_group(self):
        """Test case for delete_tag_group

        Deletes a tag group  # noqa: E501
        """
        pass

    def test_get_tag_group(self):
        """Test case for get_tag_group

        Gets the details of a specific tag group  # noqa: E501
        """
        pass

    def test_get_tag_groups(self):
        """Test case for get_tag_groups

        Gets all tag groups  # noqa: E501
        """
        pass

    def test_get_tag_in_tag_groups(self):
        """Test case for get_tag_in_tag_groups

        Gets all tags in a group  # noqa: E501
        """
        pass

    def test_remove_tag_from_tag_group(self):
        """Test case for remove_tag_from_tag_group

        Remove a tag from a tag group  # noqa: E501
        """
        pass

    def test_update_tag_group(self):
        """Test case for update_tag_group

        Modifies a tag group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
