# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.contact_list_contacts_api import ContactListContactsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestContactListContactsApi(unittest.TestCase):
    """ContactListContactsApi unit test stubs"""

    def setUp(self):
        self.api = ContactListContactsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_contact_list_contacts(self):
        """Test case for add_contact_list_contacts

        Add multiple contacts to a Contact List  # noqa: E501
        """
        pass

    def test_delete_contact_list_member(self):
        """Test case for delete_contact_list_member

        Delete a contact from a Contact List  # noqa: E501
        """
        pass

    def test_get_contacts(self):
        """Test case for get_contacts

        Gets all the contacts in a Contact List  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
