# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.pounces_api import PouncesApi  # noqa: E501
from swagger_client.rest import ApiException


class TestPouncesApi(unittest.TestCase):
    """PouncesApi unit test stubs"""

    def setUp(self):
        self.api = PouncesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_pounce(self):
        """Test case for add_pounce

        Creates a pounce  # noqa: E501
        """
        pass

    def test_delete_pounce(self):
        """Test case for delete_pounce

        Deletes the pounce  # noqa: E501
        """
        pass

    def test_get_team_member_pounces(self):
        """Test case for get_team_member_pounces

        Gets all pounces assigned to a team member  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
