# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.orgs_api import OrgsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestOrgsApi(unittest.TestCase):
    """OrgsApi unit test stubs"""

    def setUp(self):
        self.api = OrgsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_org(self):
        """Test case for get_org

        Gets information about a specific org based on its ID  # noqa: E501
        """
        pass

    def test_get_org_by_subdomain(self):
        """Test case for get_org_by_subdomain

        Gets an org by its subdomain  # noqa: E501
        """
        pass

    def test_get_org_settings_model(self):
        """Test case for get_org_settings_model

        Gets OrgSettings of the org  # noqa: E501
        """
        pass

    def test_set_org_settings(self):
        """Test case for set_org_settings

        Sets OrgSettings of the org  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
