# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.org_settings_api import OrgSettingsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestOrgSettingsApi(unittest.TestCase):
    """OrgSettingsApi unit test stubs"""

    def setUp(self):
        self.api = OrgSettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_messaging_settings(self):
        """Test case for get_messaging_settings

        Gets current messaging settings  # noqa: E501
        """
        pass

    def test_get_settings(self):
        """Test case for get_settings

        Gets current settings  # noqa: E501
        """
        pass

    def test_update_messaging_settings(self):
        """Test case for update_messaging_settings

        Updates messaging settings  # noqa: E501
        """
        pass

    def test_update_settings(self):
        """Test case for update_settings

        Updates settings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
