# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OrgExternalIdModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'value': 'str',
        'proxy_url': 'str',
        'org_id': 'int'
    }

    attribute_map = {
        'type': 'type',
        'value': 'value',
        'proxy_url': 'proxyUrl',
        'org_id': 'orgId'
    }

    def __init__(self, type=None, value=None, proxy_url=None, org_id=None):  # noqa: E501
        """OrgExternalIdModel - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._value = None
        self._proxy_url = None
        self._org_id = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if value is not None:
            self.value = value
        if proxy_url is not None:
            self.proxy_url = proxy_url
        if org_id is not None:
            self.org_id = org_id

    @property
    def type(self):
        """Gets the type of this OrgExternalIdModel.  # noqa: E501

        The type of the external id, type & value combined must be unique  # noqa: E501

        :return: The type of this OrgExternalIdModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OrgExternalIdModel.

        The type of the external id, type & value combined must be unique  # noqa: E501

        :param type: The type of this OrgExternalIdModel.  # noqa: E501
        :type: str
        """
        allowed_values = ["SALESFORCE", "BLACKBAUD"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def value(self):
        """Gets the value of this OrgExternalIdModel.  # noqa: E501

        The value of external id, type & value combined must be unique  # noqa: E501

        :return: The value of this OrgExternalIdModel.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this OrgExternalIdModel.

        The value of external id, type & value combined must be unique  # noqa: E501

        :param value: The value of this OrgExternalIdModel.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def proxy_url(self):
        """Gets the proxy_url of this OrgExternalIdModel.  # noqa: E501

        If not null, the cluster to proxy connect requests to  # noqa: E501

        :return: The proxy_url of this OrgExternalIdModel.  # noqa: E501
        :rtype: str
        """
        return self._proxy_url

    @proxy_url.setter
    def proxy_url(self, proxy_url):
        """Sets the proxy_url of this OrgExternalIdModel.

        If not null, the cluster to proxy connect requests to  # noqa: E501

        :param proxy_url: The proxy_url of this OrgExternalIdModel.  # noqa: E501
        :type: str
        """

        self._proxy_url = proxy_url

    @property
    def org_id(self):
        """Gets the org_id of this OrgExternalIdModel.  # noqa: E501

        If not null, the internal global org associated with this id  # noqa: E501

        :return: The org_id of this OrgExternalIdModel.  # noqa: E501
        :rtype: int
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this OrgExternalIdModel.

        If not null, the internal global org associated with this id  # noqa: E501

        :param org_id: The org_id of this OrgExternalIdModel.  # noqa: E501
        :type: int
        """

        self._org_id = org_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrgExternalIdModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrgExternalIdModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
