# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.integrations_api import IntegrationsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestIntegrationsApi(unittest.TestCase):
    """IntegrationsApi unit test stubs"""

    def setUp(self):
        self.api = IntegrationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_integration(self):
        """Test case for add_integration

        Creates an integration  # noqa: E501
        """
        pass

    def test_delete_integration(self):
        """Test case for delete_integration

        Deletes a integration  # noqa: E501
        """
        pass

    def test_get_integration(self):
        """Test case for get_integration

        Gets a single integration  # noqa: E501
        """
        pass

    def test_get_integrations(self):
        """Test case for get_integrations

        Gets all the integrations  # noqa: E501
        """
        pass

    def test_update_integration(self):
        """Test case for update_integration

        Update an integration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
