# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.analytics_api import AnalyticsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestAnalyticsApi(unittest.TestCase):
    """AnalyticsApi unit test stubs"""

    def setUp(self):
        self.api = AnalyticsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_agent_activity_report(self):
        """Test case for get_agent_activity_report

        Get the Agent Activity Report for the org.  # noqa: E501
        """
        pass

    def test_get_agent_activity_report_for_channel(self):
        """Test case for get_agent_activity_report_for_channel

        Get the Agent Activity Report for a specific channel.  # noqa: E501
        """
        pass

    def test_get_channel_report(self):
        """Test case for get_channel_report

        Get the Channel Report for the org.  # noqa: E501
        """
        pass

    def test_get_contact_action_report(self):
        """Test case for get_contact_action_report

        Get the Contact Action Report for the org  # noqa: E501
        """
        pass

    def test_get_custom_counters_report(self):
        """Test case for get_custom_counters_report

        Get the Custom Counters Report for the org  # noqa: E501
        """
        pass

    def test_get_custom_counters_report_for_schema(self):
        """Test case for get_custom_counters_report_for_schema

        Get the Custom Counters Report for a specific schemaId  # noqa: E501
        """
        pass

    def test_get_customer_engagement_report(self):
        """Test case for get_customer_engagement_report

        Get the Customer Engagement Report for the org  # noqa: E501
        """
        pass

    def test_get_customer_engagement_report_for_channel(self):
        """Test case for get_customer_engagement_report_for_channel

        Get the Customer Engagement Report for a specific channel  # noqa: E501
        """
        pass

    def test_get_error_report(self):
        """Test case for get_error_report

        Get the Error Report for the org  # noqa: E501
        """
        pass

    def test_get_instant_app_report(self):
        """Test case for get_instant_app_report

        Get the Instant App Report for the org  # noqa: E501
        """
        pass

    def test_get_instant_app_report_for_schema(self):
        """Test case for get_instant_app_report_for_schema

        Get the Instant App Report for a specific schema  # noqa: E501
        """
        pass

    def test_get_instant_app_schema_report(self):
        """Test case for get_instant_app_schema_report

        Get the Instant App Report for the org  # noqa: E501
        """
        pass

    def test_get_kpi_report(self):
        """Test case for get_kpi_report

        Get the KPI Report for the org  # noqa: E501
        """
        pass

    def test_get_messaging_report(self):
        """Test case for get_messaging_report

        Get the Messaging Report for the org  # noqa: E501
        """
        pass

    def test_get_messaging_report_for_channel(self):
        """Test case for get_messaging_report_for_channel

        Get the Messaging Report for a specific channel  # noqa: E501
        """
        pass

    def test_get_opt_out_report(self):
        """Test case for get_opt_out_report

        Get the Opt-Out Report for the org.  # noqa: E501
        """
        pass

    def test_get_opt_out_report_for_channel(self):
        """Test case for get_opt_out_report_for_channel

        Get the Opt-Out Report for a specific channel  # noqa: E501
        """
        pass

    def test_get_org_activity_report(self):
        """Test case for get_org_activity_report

        Get the Org Activity Report totals.  # noqa: E501
        """
        pass

    def test_get_org_activity_report_for_channel(self):
        """Test case for get_org_activity_report_for_channel

        Get the Org Activity Report totals for a specific channel.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
