# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class PouncesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_pounce(self, **kwargs):  # noqa: E501
        """Creates a pounce  # noqa: E501

        _in snippets: platform.api.pounces.addPounce_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_pounce(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PounceModel body:
        :return: PounceModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_pounce_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_pounce_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_pounce_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a pounce  # noqa: E501

        _in snippets: platform.api.pounces.addPounce_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_pounce_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PounceModel body:
        :return: PounceModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_pounce" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/pounces', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PounceModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_pounce(self, pounce_id, **kwargs):  # noqa: E501
        """Deletes the pounce  # noqa: E501

        _in snippets: platform.api.pounces.deletePounce_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_pounce(pounce_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int pounce_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_pounce_with_http_info(pounce_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_pounce_with_http_info(pounce_id, **kwargs)  # noqa: E501
            return data

    def delete_pounce_with_http_info(self, pounce_id, **kwargs):  # noqa: E501
        """Deletes the pounce  # noqa: E501

        _in snippets: platform.api.pounces.deletePounce_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_pounce_with_http_info(pounce_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int pounce_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pounce_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_pounce" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'pounce_id' is set
        if ('pounce_id' not in params or
                params['pounce_id'] is None):
            raise ValueError("Missing the required parameter `pounce_id` when calling `delete_pounce`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'pounce_id' in params:
            path_params['pounceId'] = params['pounce_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/pounces/{pounceId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_member_pounces(self, team_member_id, **kwargs):  # noqa: E501
        """Gets all pounces assigned to a team member  # noqa: E501

        _in snippets: platform.api.pounces.getTeamMemberPounces_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_member_pounces(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: list[PounceModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_member_pounces_with_http_info(team_member_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_team_member_pounces_with_http_info(team_member_id, **kwargs)  # noqa: E501
            return data

    def get_team_member_pounces_with_http_info(self, team_member_id, **kwargs):  # noqa: E501
        """Gets all pounces assigned to a team member  # noqa: E501

        _in snippets: platform.api.pounces.getTeamMemberPounces_  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_member_pounces_with_http_info(team_member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int team_member_id: (required)
        :return: list[PounceModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['team_member_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_member_pounces" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'team_member_id' is set
        if ('team_member_id' not in params or
                params['team_member_id'] is None):
            raise ValueError("Missing the required parameter `team_member_id` when calling `get_team_member_pounces`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'team_member_id' in params:
            path_params['teamMemberId'] = params['team_member_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['org_token']  # noqa: E501

        return self.api_client.call_api(
            '/pounces/{teamMemberId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PounceModel]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
