# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.org_channels_api import OrgChannelsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestOrgChannelsApi(unittest.TestCase):
    """OrgChannelsApi unit test stubs"""

    def setUp(self):
        self.api = OrgChannelsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_org_channel1(self):
        """Test case for add_org_channel1

        Creates an org channel  # noqa: E501
        """
        pass

    def test_delete_org_channel1(self):
        """Test case for delete_org_channel1

        Delete an org channel  # noqa: E501
        """
        pass

    def test_get_org_channel(self):
        """Test case for get_org_channel

        Gets the details for a specific org channel  # noqa: E501
        """
        pass

    def test_get_org_channel_conversations(self):
        """Test case for get_org_channel_conversations

        Gets the conversation details for a specific org channel  # noqa: E501
        """
        pass

    def test_get_org_channels1(self):
        """Test case for get_org_channels1

        Gets all the org channels for the org  # noqa: E501
        """
        pass

    def test_get_pool_subchannel(self):
        """Test case for get_pool_subchannel

        For pool channels, gets the details of a specific subchannel in the pool  # noqa: E501
        """
        pass

    def test_get_pool_subchannels(self):
        """Test case for get_pool_subchannels

        For pool channels, gets the subchannels in the pool  # noqa: E501
        """
        pass

    def test_update_org_channel(self):
        """Test case for update_org_channel

        Updates an org channel  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
