# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.bulk_actions_api import BulkActionsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestBulkActionsApi(unittest.TestCase):
    """BulkActionsApi unit test stubs"""

    def setUp(self):
        self.api = BulkActionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_bulk_action(self):
        """Test case for abort_bulk_action

        Abort a Bulk Action  # noqa: E501
        """
        pass

    def test_add_bulk_action(self):
        """Test case for add_bulk_action

        Creates a Bulk Action and starts it  # noqa: E501
        """
        pass

    def test_disable_variant(self):
        """Test case for disable_variant

        Disable a vairant if the BulkAction is using A/B testing  # noqa: E501
        """
        pass

    def test_get_bulk_action(self):
        """Test case for get_bulk_action

        Gets a specific Bulk Action  # noqa: E501
        """
        pass

    def test_get_bulk_actions(self):
        """Test case for get_bulk_actions

        Gets all Bulk Actions  # noqa: E501
        """
        pass

    def test_get_contacts_for_resolution(self):
        """Test case for get_contacts_for_resolution

        Get a list of customers for a particular Resolution string for this Bulk Action  # noqa: E501
        """
        pass

    def test_get_resolution_counts(self):
        """Test case for get_resolution_counts

        Retrieves the counts for each resolution string for this Bulk Action  # noqa: E501
        """
        pass

    def test_perform_action(self):
        """Test case for perform_action

        Performs an action on the contacts or subset of contacts in the Bulk Action  # noqa: E501
        """
        pass

    def test_set_bulk_resolution(self):
        """Test case for set_bulk_resolution

        Set a bulk action resolution string for a contact.  # noqa: E501
        """
        pass

    def test_unlock_bulk_action_contact(self):
        """Test case for unlock_bulk_action_contact

        Confirms a Bulk Action that is set to require manual sending  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
