# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsMessagingReportListItemModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp_epoch': 'int',
        'total_messages': 'int',
        'outgoing_messages': 'int',
        'incoming_messages': 'int',
        'outgoing_bot': 'int',
        'outgoing_automation': 'int',
        'outgoing_macro': 'int',
        'outgoing_agent': 'int',
        'outgoing_contact_action': 'int',
        'outgoing_scheduled': 'int',
        'outgoing_api': 'int',
        'outgoing_channel_app': 'int',
        'outgoing_agent_app': 'int',
        'outgoing_customer_app': 'int',
        'engaged_customers': 'int',
        'outgoing_messages_text': 'int',
        'outgoing_messages_instant_app': 'int',
        'outgoing_messages_file': 'int',
        'outgoing_messages_mms': 'int',
        'outgoing_messages_system': 'int',
        'outgoing_contact_action_manual': 'int',
        'outgoing_contact_action_auto': 'int',
        'incoming_messages_text': 'int',
        'incoming_messages_mms': 'int',
        'total_segments': 'int',
        'outgoing_segments': 'int',
        'incoming_segments': 'int'
    }

    attribute_map = {
        'timestamp_epoch': 'timestampEpoch',
        'total_messages': 'totalMessages',
        'outgoing_messages': 'outgoingMessages',
        'incoming_messages': 'incomingMessages',
        'outgoing_bot': 'outgoingBot',
        'outgoing_automation': 'outgoingAutomation',
        'outgoing_macro': 'outgoingMacro',
        'outgoing_agent': 'outgoingAgent',
        'outgoing_contact_action': 'outgoingContactAction',
        'outgoing_scheduled': 'outgoingScheduled',
        'outgoing_api': 'outgoingApi',
        'outgoing_channel_app': 'outgoingChannelApp',
        'outgoing_agent_app': 'outgoingAgentApp',
        'outgoing_customer_app': 'outgoingCustomerApp',
        'engaged_customers': 'engagedCustomers',
        'outgoing_messages_text': 'outgoingMessagesText',
        'outgoing_messages_instant_app': 'outgoingMessagesInstantApp',
        'outgoing_messages_file': 'outgoingMessagesFile',
        'outgoing_messages_mms': 'outgoingMessagesMms',
        'outgoing_messages_system': 'outgoingMessagesSystem',
        'outgoing_contact_action_manual': 'outgoingContactActionManual',
        'outgoing_contact_action_auto': 'outgoingContactActionAuto',
        'incoming_messages_text': 'incomingMessagesText',
        'incoming_messages_mms': 'incomingMessagesMms',
        'total_segments': 'totalSegments',
        'outgoing_segments': 'outgoingSegments',
        'incoming_segments': 'incomingSegments'
    }

    def __init__(self, timestamp_epoch=None, total_messages=None, outgoing_messages=None, incoming_messages=None, outgoing_bot=None, outgoing_automation=None, outgoing_macro=None, outgoing_agent=None, outgoing_contact_action=None, outgoing_scheduled=None, outgoing_api=None, outgoing_channel_app=None, outgoing_agent_app=None, outgoing_customer_app=None, engaged_customers=None, outgoing_messages_text=None, outgoing_messages_instant_app=None, outgoing_messages_file=None, outgoing_messages_mms=None, outgoing_messages_system=None, outgoing_contact_action_manual=None, outgoing_contact_action_auto=None, incoming_messages_text=None, incoming_messages_mms=None, total_segments=None, outgoing_segments=None, incoming_segments=None):  # noqa: E501
        """AnalyticsMessagingReportListItemModel - a model defined in Swagger"""  # noqa: E501
        self._timestamp_epoch = None
        self._total_messages = None
        self._outgoing_messages = None
        self._incoming_messages = None
        self._outgoing_bot = None
        self._outgoing_automation = None
        self._outgoing_macro = None
        self._outgoing_agent = None
        self._outgoing_contact_action = None
        self._outgoing_scheduled = None
        self._outgoing_api = None
        self._outgoing_channel_app = None
        self._outgoing_agent_app = None
        self._outgoing_customer_app = None
        self._engaged_customers = None
        self._outgoing_messages_text = None
        self._outgoing_messages_instant_app = None
        self._outgoing_messages_file = None
        self._outgoing_messages_mms = None
        self._outgoing_messages_system = None
        self._outgoing_contact_action_manual = None
        self._outgoing_contact_action_auto = None
        self._incoming_messages_text = None
        self._incoming_messages_mms = None
        self._total_segments = None
        self._outgoing_segments = None
        self._incoming_segments = None
        self.discriminator = None
        if timestamp_epoch is not None:
            self.timestamp_epoch = timestamp_epoch
        if total_messages is not None:
            self.total_messages = total_messages
        if outgoing_messages is not None:
            self.outgoing_messages = outgoing_messages
        if incoming_messages is not None:
            self.incoming_messages = incoming_messages
        if outgoing_bot is not None:
            self.outgoing_bot = outgoing_bot
        if outgoing_automation is not None:
            self.outgoing_automation = outgoing_automation
        if outgoing_macro is not None:
            self.outgoing_macro = outgoing_macro
        if outgoing_agent is not None:
            self.outgoing_agent = outgoing_agent
        if outgoing_contact_action is not None:
            self.outgoing_contact_action = outgoing_contact_action
        if outgoing_scheduled is not None:
            self.outgoing_scheduled = outgoing_scheduled
        if outgoing_api is not None:
            self.outgoing_api = outgoing_api
        if outgoing_channel_app is not None:
            self.outgoing_channel_app = outgoing_channel_app
        if outgoing_agent_app is not None:
            self.outgoing_agent_app = outgoing_agent_app
        if outgoing_customer_app is not None:
            self.outgoing_customer_app = outgoing_customer_app
        if engaged_customers is not None:
            self.engaged_customers = engaged_customers
        if outgoing_messages_text is not None:
            self.outgoing_messages_text = outgoing_messages_text
        if outgoing_messages_instant_app is not None:
            self.outgoing_messages_instant_app = outgoing_messages_instant_app
        if outgoing_messages_file is not None:
            self.outgoing_messages_file = outgoing_messages_file
        if outgoing_messages_mms is not None:
            self.outgoing_messages_mms = outgoing_messages_mms
        if outgoing_messages_system is not None:
            self.outgoing_messages_system = outgoing_messages_system
        if outgoing_contact_action_manual is not None:
            self.outgoing_contact_action_manual = outgoing_contact_action_manual
        if outgoing_contact_action_auto is not None:
            self.outgoing_contact_action_auto = outgoing_contact_action_auto
        if incoming_messages_text is not None:
            self.incoming_messages_text = incoming_messages_text
        if incoming_messages_mms is not None:
            self.incoming_messages_mms = incoming_messages_mms
        if total_segments is not None:
            self.total_segments = total_segments
        if outgoing_segments is not None:
            self.outgoing_segments = outgoing_segments
        if incoming_segments is not None:
            self.incoming_segments = incoming_segments

    @property
    def timestamp_epoch(self):
        """Gets the timestamp_epoch of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The timestamp at the start of the default group-by window as a Unix timestamp.  # noqa: E501

        :return: The timestamp_epoch of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._timestamp_epoch

    @timestamp_epoch.setter
    def timestamp_epoch(self, timestamp_epoch):
        """Sets the timestamp_epoch of this AnalyticsMessagingReportListItemModel.

        The timestamp at the start of the default group-by window as a Unix timestamp.  # noqa: E501

        :param timestamp_epoch: The timestamp_epoch of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._timestamp_epoch = timestamp_epoch

    @property
    def total_messages(self):
        """Gets the total_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent or received during the default group-by window.  # noqa: E501

        :return: The total_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._total_messages

    @total_messages.setter
    def total_messages(self, total_messages):
        """Sets the total_messages of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent or received during the default group-by window.  # noqa: E501

        :param total_messages: The total_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._total_messages = total_messages

    @property
    def outgoing_messages(self):
        """Gets the outgoing_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages

    @outgoing_messages.setter
    def outgoing_messages(self, outgoing_messages):
        """Sets the outgoing_messages of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent during the default group-by window.  # noqa: E501

        :param outgoing_messages: The outgoing_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages = outgoing_messages

    @property
    def incoming_messages(self):
        """Gets the incoming_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages received during the default group-by window.  # noqa: E501

        :return: The incoming_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_messages

    @incoming_messages.setter
    def incoming_messages(self, incoming_messages):
        """Sets the incoming_messages of this AnalyticsMessagingReportListItemModel.

        The total number of messages received during the default group-by window.  # noqa: E501

        :param incoming_messages: The incoming_messages of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._incoming_messages = incoming_messages

    @property
    def outgoing_bot(self):
        """Gets the outgoing_bot of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent by a bot during the default group-by window.  # noqa: E501

        :return: The outgoing_bot of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_bot

    @outgoing_bot.setter
    def outgoing_bot(self, outgoing_bot):
        """Sets the outgoing_bot of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent by a bot during the default group-by window.  # noqa: E501

        :param outgoing_bot: The outgoing_bot of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_bot = outgoing_bot

    @property
    def outgoing_automation(self):
        """Gets the outgoing_automation of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent by an automation during the default group-by window.  # noqa: E501

        :return: The outgoing_automation of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_automation

    @outgoing_automation.setter
    def outgoing_automation(self, outgoing_automation):
        """Sets the outgoing_automation of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent by an automation during the default group-by window.  # noqa: E501

        :param outgoing_automation: The outgoing_automation of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_automation = outgoing_automation

    @property
    def outgoing_macro(self):
        """Gets the outgoing_macro of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent by an agent during the default group-by window.  # noqa: E501

        :return: The outgoing_macro of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_macro

    @outgoing_macro.setter
    def outgoing_macro(self, outgoing_macro):
        """Sets the outgoing_macro of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent by an agent during the default group-by window.  # noqa: E501

        :param outgoing_macro: The outgoing_macro of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_macro = outgoing_macro

    @property
    def outgoing_agent(self):
        """Gets the outgoing_agent of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent by a Library Action during the default group-by window.  # noqa: E501

        :return: The outgoing_agent of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_agent

    @outgoing_agent.setter
    def outgoing_agent(self, outgoing_agent):
        """Sets the outgoing_agent of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent by a Library Action during the default group-by window.  # noqa: E501

        :param outgoing_agent: The outgoing_agent of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_agent = outgoing_agent

    @property
    def outgoing_contact_action(self):
        """Gets the outgoing_contact_action of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of contact action messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_contact_action of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_contact_action

    @outgoing_contact_action.setter
    def outgoing_contact_action(self, outgoing_contact_action):
        """Sets the outgoing_contact_action of this AnalyticsMessagingReportListItemModel.

        The total number of contact action messages sent during the default group-by window.  # noqa: E501

        :param outgoing_contact_action: The outgoing_contact_action of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_contact_action = outgoing_contact_action

    @property
    def outgoing_scheduled(self):
        """Gets the outgoing_scheduled of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of scheduled messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_scheduled of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_scheduled

    @outgoing_scheduled.setter
    def outgoing_scheduled(self, outgoing_scheduled):
        """Sets the outgoing_scheduled of this AnalyticsMessagingReportListItemModel.

        The total number of scheduled messages sent during the default group-by window.  # noqa: E501

        :param outgoing_scheduled: The outgoing_scheduled of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_scheduled = outgoing_scheduled

    @property
    def outgoing_api(self):
        """Gets the outgoing_api of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via API during the default group-by window.  # noqa: E501

        :return: The outgoing_api of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_api

    @outgoing_api.setter
    def outgoing_api(self, outgoing_api):
        """Sets the outgoing_api of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via API during the default group-by window.  # noqa: E501

        :param outgoing_api: The outgoing_api of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_api = outgoing_api

    @property
    def outgoing_channel_app(self):
        """Gets the outgoing_channel_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via Channel App during the default group-by window.  # noqa: E501

        :return: The outgoing_channel_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_channel_app

    @outgoing_channel_app.setter
    def outgoing_channel_app(self, outgoing_channel_app):
        """Sets the outgoing_channel_app of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via Channel App during the default group-by window.  # noqa: E501

        :param outgoing_channel_app: The outgoing_channel_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_channel_app = outgoing_channel_app

    @property
    def outgoing_agent_app(self):
        """Gets the outgoing_agent_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via Agent App during the default group-by window.  # noqa: E501

        :return: The outgoing_agent_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_agent_app

    @outgoing_agent_app.setter
    def outgoing_agent_app(self, outgoing_agent_app):
        """Sets the outgoing_agent_app of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via Agent App during the default group-by window.  # noqa: E501

        :param outgoing_agent_app: The outgoing_agent_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_agent_app = outgoing_agent_app

    @property
    def outgoing_customer_app(self):
        """Gets the outgoing_customer_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via Customer App during the default group-by window.  # noqa: E501

        :return: The outgoing_customer_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_customer_app

    @outgoing_customer_app.setter
    def outgoing_customer_app(self, outgoing_customer_app):
        """Sets the outgoing_customer_app of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via Customer App during the default group-by window.  # noqa: E501

        :param outgoing_customer_app: The outgoing_customer_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_customer_app = outgoing_customer_app

    @property
    def engaged_customers(self):
        """Gets the engaged_customers of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of engaged customers during the default group-by window.  # noqa: E501

        :return: The engaged_customers of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._engaged_customers

    @engaged_customers.setter
    def engaged_customers(self, engaged_customers):
        """Sets the engaged_customers of this AnalyticsMessagingReportListItemModel.

        The total number of engaged customers during the default group-by window.  # noqa: E501

        :param engaged_customers: The engaged_customers of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._engaged_customers = engaged_customers

    @property
    def outgoing_messages_text(self):
        """Gets the outgoing_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of text messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_text

    @outgoing_messages_text.setter
    def outgoing_messages_text(self, outgoing_messages_text):
        """Sets the outgoing_messages_text of this AnalyticsMessagingReportListItemModel.

        The total number of text messages sent during the default group-by window.  # noqa: E501

        :param outgoing_messages_text: The outgoing_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_text = outgoing_messages_text

    @property
    def outgoing_messages_instant_app(self):
        """Gets the outgoing_messages_instant_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of Instant Apps sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_instant_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_instant_app

    @outgoing_messages_instant_app.setter
    def outgoing_messages_instant_app(self, outgoing_messages_instant_app):
        """Sets the outgoing_messages_instant_app of this AnalyticsMessagingReportListItemModel.

        The total number of Instant Apps sent during the default group-by window.  # noqa: E501

        :param outgoing_messages_instant_app: The outgoing_messages_instant_app of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_instant_app = outgoing_messages_instant_app

    @property
    def outgoing_messages_file(self):
        """Gets the outgoing_messages_file of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of files sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_file of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_file

    @outgoing_messages_file.setter
    def outgoing_messages_file(self, outgoing_messages_file):
        """Sets the outgoing_messages_file of this AnalyticsMessagingReportListItemModel.

        The total number of files sent during the default group-by window.  # noqa: E501

        :param outgoing_messages_file: The outgoing_messages_file of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_file = outgoing_messages_file

    @property
    def outgoing_messages_mms(self):
        """Gets the outgoing_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of MMS messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_mms

    @outgoing_messages_mms.setter
    def outgoing_messages_mms(self, outgoing_messages_mms):
        """Sets the outgoing_messages_mms of this AnalyticsMessagingReportListItemModel.

        The total number of MMS messages sent during the default group-by window.  # noqa: E501

        :param outgoing_messages_mms: The outgoing_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_mms = outgoing_messages_mms

    @property
    def outgoing_messages_system(self):
        """Gets the outgoing_messages_system of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of internal system messages sent during the default group-by window.  # noqa: E501

        :return: The outgoing_messages_system of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_messages_system

    @outgoing_messages_system.setter
    def outgoing_messages_system(self, outgoing_messages_system):
        """Sets the outgoing_messages_system of this AnalyticsMessagingReportListItemModel.

        The total number of internal system messages sent during the default group-by window.  # noqa: E501

        :param outgoing_messages_system: The outgoing_messages_system of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_messages_system = outgoing_messages_system

    @property
    def outgoing_contact_action_manual(self):
        """Gets the outgoing_contact_action_manual of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via manual (P2P) Contact Action during the default group-by window.  # noqa: E501

        :return: The outgoing_contact_action_manual of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_contact_action_manual

    @outgoing_contact_action_manual.setter
    def outgoing_contact_action_manual(self, outgoing_contact_action_manual):
        """Sets the outgoing_contact_action_manual of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via manual (P2P) Contact Action during the default group-by window.  # noqa: E501

        :param outgoing_contact_action_manual: The outgoing_contact_action_manual of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_contact_action_manual = outgoing_contact_action_manual

    @property
    def outgoing_contact_action_auto(self):
        """Gets the outgoing_contact_action_auto of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of messages sent via automatic (A2P) Contact Action during the default group-by window.  # noqa: E501

        :return: The outgoing_contact_action_auto of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_contact_action_auto

    @outgoing_contact_action_auto.setter
    def outgoing_contact_action_auto(self, outgoing_contact_action_auto):
        """Sets the outgoing_contact_action_auto of this AnalyticsMessagingReportListItemModel.

        The total number of messages sent via automatic (A2P) Contact Action during the default group-by window.  # noqa: E501

        :param outgoing_contact_action_auto: The outgoing_contact_action_auto of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_contact_action_auto = outgoing_contact_action_auto

    @property
    def incoming_messages_text(self):
        """Gets the incoming_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of text messages received during the default group-by window.  # noqa: E501

        :return: The incoming_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_messages_text

    @incoming_messages_text.setter
    def incoming_messages_text(self, incoming_messages_text):
        """Sets the incoming_messages_text of this AnalyticsMessagingReportListItemModel.

        The total number of text messages received during the default group-by window.  # noqa: E501

        :param incoming_messages_text: The incoming_messages_text of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._incoming_messages_text = incoming_messages_text

    @property
    def incoming_messages_mms(self):
        """Gets the incoming_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of MMS messages received during the default group-by window.  # noqa: E501

        :return: The incoming_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_messages_mms

    @incoming_messages_mms.setter
    def incoming_messages_mms(self, incoming_messages_mms):
        """Sets the incoming_messages_mms of this AnalyticsMessagingReportListItemModel.

        The total number of MMS messages received during the default group-by window.  # noqa: E501

        :param incoming_messages_mms: The incoming_messages_mms of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._incoming_messages_mms = incoming_messages_mms

    @property
    def total_segments(self):
        """Gets the total_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of segments sent and received during the default group-by window.  # noqa: E501

        :return: The total_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._total_segments

    @total_segments.setter
    def total_segments(self, total_segments):
        """Sets the total_segments of this AnalyticsMessagingReportListItemModel.

        The total number of segments sent and received during the default group-by window.  # noqa: E501

        :param total_segments: The total_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._total_segments = total_segments

    @property
    def outgoing_segments(self):
        """Gets the outgoing_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of segments sent during the default group-by window.  # noqa: E501

        :return: The outgoing_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._outgoing_segments

    @outgoing_segments.setter
    def outgoing_segments(self, outgoing_segments):
        """Sets the outgoing_segments of this AnalyticsMessagingReportListItemModel.

        The total number of segments sent during the default group-by window.  # noqa: E501

        :param outgoing_segments: The outgoing_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._outgoing_segments = outgoing_segments

    @property
    def incoming_segments(self):
        """Gets the incoming_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501

        The total number of segments received during the default group-by window.  # noqa: E501

        :return: The incoming_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :rtype: int
        """
        return self._incoming_segments

    @incoming_segments.setter
    def incoming_segments(self, incoming_segments):
        """Sets the incoming_segments of this AnalyticsMessagingReportListItemModel.

        The total number of segments received during the default group-by window.  # noqa: E501

        :param incoming_segments: The incoming_segments of this AnalyticsMessagingReportListItemModel.  # noqa: E501
        :type: int
        """

        self._incoming_segments = incoming_segments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsMessagingReportListItemModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsMessagingReportListItemModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
