# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.automations_api import AutomationsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestAutomationsApi(unittest.TestCase):
    """AutomationsApi unit test stubs"""

    def setUp(self):
        self.api = AutomationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_org_channel(self):
        """Test case for add_org_channel

        Adds an OrgChannel to an automation  # noqa: E501
        """
        pass

    def test_create_automation(self):
        """Test case for create_automation

        Creates a new automation  # noqa: E501
        """
        pass

    def test_delete_automation(self):
        """Test case for delete_automation

        Deletes an automation  # noqa: E501
        """
        pass

    def test_delete_org_channel(self):
        """Test case for delete_org_channel

        Removes an OrgChannel from an automation  # noqa: E501
        """
        pass

    def test_get_automation(self):
        """Test case for get_automation

        Gets the details of a specific automation  # noqa: E501
        """
        pass

    def test_get_automations(self):
        """Test case for get_automations

        Gets all the automations in the org  # noqa: E501
        """
        pass

    def test_get_org_channels(self):
        """Test case for get_org_channels

        Gets a list of the OrgChannel from an automation  # noqa: E501
        """
        pass

    def test_update_automation(self):
        """Test case for update_automation

        Modifies an automation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
