# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.data_api import DataApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self):
        self.api = DataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_data(self):
        """Test case for delete_data

        Deletes one key of data for a specific data entity  # noqa: E501
        """
        pass

    def test_get_data(self):
        """Test case for get_data

        Gets all the data for a specific data entity  # noqa: E501
        """
        pass

    def test_get_data_by_key(self):
        """Test case for get_data_by_key

        Gets one key of data for a specific data entity  # noqa: E501
        """
        pass

    def test_get_data_default(self):
        """Test case for get_data_default

        Get the default values for a specific customer data key  # noqa: E501
        """
        pass

    def test_get_data_defaults(self):
        """Test case for get_data_defaults

        Get the default values for customer data keys  # noqa: E501
        """
        pass

    def test_set_data(self):
        """Test case for set_data

        Sets all the data for a specific data entity (unmentioned keys are removed)  # noqa: E501
        """
        pass

    def test_set_data_default(self):
        """Test case for set_data_default

        Set the default value for a specific customer data key  # noqa: E501
        """
        pass

    def test_update_data(self):
        """Test case for update_data

        Updates data for a specific data entity (does not modify unmentioned keys)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
