# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.instant_app_schemas_api import InstantAppSchemasApi  # noqa: E501
from swagger_client.rest import ApiException


class TestInstantAppSchemasApi(unittest.TestCase):
    """InstantAppSchemasApi unit test stubs"""

    def setUp(self):
        self.api = InstantAppSchemasApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_schema(self):
        """Test case for activate_schema

        Activates or deactivates an Instant App Schema  # noqa: E501
        """
        pass

    def test_add_schema(self):
        """Test case for add_schema

        Creates an Instant App Schema  # noqa: E501
        """
        pass

    def test_delete_schema(self):
        """Test case for delete_schema

        Deletes an Instant App Schema  # noqa: E501
        """
        pass

    def test_get_schema(self):
        """Test case for get_schema

        Gets a specific Instant App Schema  # noqa: E501
        """
        pass

    def test_get_schema_info(self):
        """Test case for get_schema_info

        Gets details about a specific Instant App Schema  # noqa: E501
        """
        pass

    def test_get_schema_infos(self):
        """Test case for get_schema_infos

        Gets details about all of the Instant App Schemas in the org  # noqa: E501
        """
        pass

    def test_is_schema_active(self):
        """Test case for is_schema_active

        Gets the active status of an Instant App Schema  # noqa: E501
        """
        pass

    def test_update_schema(self):
        """Test case for update_schema

        Modifies an Instant App Schema  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
