# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.pool_channels_api import PoolChannelsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestPoolChannelsApi(unittest.TestCase):
    """PoolChannelsApi unit test stubs"""

    def setUp(self):
        self.api = PoolChannelsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_channels(self):
        """Test case for add_channels

        Provision phone numbers for pool  # noqa: E501
        """
        pass

    def test_delete(self):
        """Test case for delete

        Delete a channel from a pool  # noqa: E501
        """
        pass

    def test_get(self):
        """Test case for get

        Get a specific channel in a pool  # noqa: E501
        """
        pass

    def test_get_all(self):
        """Test case for get_all

        Get all the channels in a pool  # noqa: E501
        """
        pass

    def test_update_status(self):
        """Test case for update_status

        Updates the status of a specific channel in a pool  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
