# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.team_members_api import TeamMembersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestTeamMembersApi(unittest.TestCase):
    """TeamMembersApi unit test stubs"""

    def setUp(self):
        self.api = TeamMembersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_identity1(self):
        """Test case for add_identity1

        Adds an identity to a team member  # noqa: E501
        """
        pass

    def test_add_team_member(self):
        """Test case for add_team_member

        Creates a team member  # noqa: E501
        """
        pass

    def test_delete_team_member(self):
        """Test case for delete_team_member

        Deletes a team member  # noqa: E501
        """
        pass

    def test_get_aggregate_permissions(self):
        """Test case for get_aggregate_permissions

        Gets a team member's permissions  # noqa: E501
        """
        pass

    def test_get_org_channel_permission1(self):
        """Test case for get_org_channel_permission1

        Gets a team member's orgChannel permission  # noqa: E501
        """
        pass

    def test_get_org_channel_permissions1(self):
        """Test case for get_org_channel_permissions1

        Gets a team member's orgChannel permissions  # noqa: E501
        """
        pass

    def test_get_org_channels_with_permissions(self):
        """Test case for get_org_channels_with_permissions

        Gets the org channels a team member has permissions for  # noqa: E501
        """
        pass

    def test_get_permission1(self):
        """Test case for get_permission1

        Gets a team member's permission  # noqa: E501
        """
        pass

    def test_get_permissions1(self):
        """Test case for get_permissions1

        Gets a team member's permissions  # noqa: E501
        """
        pass

    def test_get_private_apps(self):
        """Test case for get_private_apps

        Installs private agent app for the given agent  # noqa: E501
        """
        pass

    def test_get_shared_apps(self):
        """Test case for get_shared_apps

        Gets installed shared agent apps  # noqa: E501
        """
        pass

    def test_get_team_activity(self):
        """Test case for get_team_activity

        Returns a snapshot of team activity  # noqa: E501
        """
        pass

    def test_get_team_member(self):
        """Test case for get_team_member

        Gets the details for a specific team member  # noqa: E501
        """
        pass

    def test_get_team_member_activity(self):
        """Test case for get_team_member_activity

        Returns a snapshot of a team members activity  # noqa: E501
        """
        pass

    def test_get_team_member_notifications(self):
        """Test case for get_team_member_notifications

        Gets a team member's notification settings  # noqa: E501
        """
        pass

    def test_get_team_members(self):
        """Test case for get_team_members

        Gets all the team members in the org  # noqa: E501
        """
        pass

    def test_install_private_app(self):
        """Test case for install_private_app

        Installs private agent app for the given agent  # noqa: E501
        """
        pass

    def test_install_shared_app(self):
        """Test case for install_shared_app

        Installs shared agent app for all agents  # noqa: E501
        """
        pass

    def test_set_org_channel_permission(self):
        """Test case for set_org_channel_permission

        Sets a team member's orgChannel permission  # noqa: E501
        """
        pass

    def test_set_org_channel_permissions1(self):
        """Test case for set_org_channel_permissions1

        Sets a team member's orgChannel permissions  # noqa: E501
        """
        pass

    def test_set_permission(self):
        """Test case for set_permission

        Sets a team member's permission  # noqa: E501
        """
        pass

    def test_set_permissions1(self):
        """Test case for set_permissions1

        Sets a team member's permissions  # noqa: E501
        """
        pass

    def test_set_team_member_notifications(self):
        """Test case for set_team_member_notifications

        Sets a team member's notification settings  # noqa: E501
        """
        pass

    def test_update_team_member(self):
        """Test case for update_team_member

        Updates a team member  # noqa: E501
        """
        pass

    def test_upload_file_to_team_members(self):
        """Test case for upload_file_to_team_members

        Upload a file for specific team member(s) to access  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
