# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.group_members_api import GroupMembersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestGroupMembersApi(unittest.TestCase):
    """GroupMembersApi unit test stubs"""

    def setUp(self):
        self.api = GroupMembersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_group_member(self):
        """Test case for add_group_member

        Add a member to a group  # noqa: E501
        """
        pass

    def test_delete_group_member(self):
        """Test case for delete_group_member

        Delete a member from a group  # noqa: E501
        """
        pass

    def test_get_group_members(self):
        """Test case for get_group_members

        Gets all the members of a group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
