# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ChannelIdModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'org_name': 'str',
        'org_phone_number': 'str',
        'customer_phone_number': 'str',
        'timestamps': 'list[int]'
    }

    attribute_map = {
        'org_name': 'orgName',
        'org_phone_number': 'orgPhoneNumber',
        'customer_phone_number': 'customerPhoneNumber',
        'timestamps': 'timestamps'
    }

    def __init__(self, org_name=None, org_phone_number=None, customer_phone_number=None, timestamps=None):  # noqa: E501
        """ChannelIdModel - a model defined in Swagger"""  # noqa: E501
        self._org_name = None
        self._org_phone_number = None
        self._customer_phone_number = None
        self._timestamps = None
        self.discriminator = None
        if org_name is not None:
            self.org_name = org_name
        if org_phone_number is not None:
            self.org_phone_number = org_phone_number
        if customer_phone_number is not None:
            self.customer_phone_number = customer_phone_number
        if timestamps is not None:
            self.timestamps = timestamps

    @property
    def org_name(self):
        """Gets the org_name of this ChannelIdModel.  # noqa: E501


        :return: The org_name of this ChannelIdModel.  # noqa: E501
        :rtype: str
        """
        return self._org_name

    @org_name.setter
    def org_name(self, org_name):
        """Sets the org_name of this ChannelIdModel.


        :param org_name: The org_name of this ChannelIdModel.  # noqa: E501
        :type: str
        """

        self._org_name = org_name

    @property
    def org_phone_number(self):
        """Gets the org_phone_number of this ChannelIdModel.  # noqa: E501


        :return: The org_phone_number of this ChannelIdModel.  # noqa: E501
        :rtype: str
        """
        return self._org_phone_number

    @org_phone_number.setter
    def org_phone_number(self, org_phone_number):
        """Sets the org_phone_number of this ChannelIdModel.


        :param org_phone_number: The org_phone_number of this ChannelIdModel.  # noqa: E501
        :type: str
        """

        self._org_phone_number = org_phone_number

    @property
    def customer_phone_number(self):
        """Gets the customer_phone_number of this ChannelIdModel.  # noqa: E501


        :return: The customer_phone_number of this ChannelIdModel.  # noqa: E501
        :rtype: str
        """
        return self._customer_phone_number

    @customer_phone_number.setter
    def customer_phone_number(self, customer_phone_number):
        """Sets the customer_phone_number of this ChannelIdModel.


        :param customer_phone_number: The customer_phone_number of this ChannelIdModel.  # noqa: E501
        :type: str
        """

        self._customer_phone_number = customer_phone_number

    @property
    def timestamps(self):
        """Gets the timestamps of this ChannelIdModel.  # noqa: E501


        :return: The timestamps of this ChannelIdModel.  # noqa: E501
        :rtype: list[int]
        """
        return self._timestamps

    @timestamps.setter
    def timestamps(self, timestamps):
        """Sets the timestamps of this ChannelIdModel.


        :param timestamps: The timestamps of this ChannelIdModel.  # noqa: E501
        :type: list[int]
        """

        self._timestamps = timestamps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChannelIdModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelIdModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
