# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.instant_apps_api import InstantAppsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestInstantAppsApi(unittest.TestCase):
    """InstantAppsApi unit test stubs"""

    def setUp(self):
        self.api = InstantAppsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_audit_message(self):
        """Test case for add_audit_message

        Add a new audit message  # noqa: E501
        """
        pass

    def test_cancel_timers(self):
        """Test case for cancel_timers

        Cancels any outstanding timers matching the params  # noqa: E501
        """
        pass

    def test_get_audit_messages(self):
        """Test case for get_audit_messages

        Gets the audit trail messages of an Instant App  # noqa: E501
        """
        pass

    def test_get_data1(self):
        """Test case for get_data1

        Gets the value for every element of the Instant App  # noqa: E501
        """
        pass

    def test_get_instant_app(self):
        """Test case for get_instant_app

        Gets the details of a specific Instant App  # noqa: E501
        """
        pass

    def test_is_instant_app_locked(self):
        """Test case for is_instant_app_locked

        Gets the lock status of an Instant App  # noqa: E501
        """
        pass

    def test_save_data(self):
        """Test case for save_data

        Updates the value for every element of the Instant App given  # noqa: E501
        """
        pass

    def test_set_icon(self):
        """Test case for set_icon

        Updates the icon and icon label for an instant app  # noqa: E501
        """
        pass

    def test_set_instant_app_locked(self):
        """Test case for set_instant_app_locked

        Set whether an Instant App is locked  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
