# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.event_endpoints_api import EventEndpointsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestEventEndpointsApi(unittest.TestCase):
    """EventEndpointsApi unit test stubs"""

    def setUp(self):
        self.api = EventEndpointsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_event_endpoint(self):
        """Test case for add_event_endpoint

        Creates an Event Endpoint  # noqa: E501
        """
        pass

    def test_delete_event_endpoint(self):
        """Test case for delete_event_endpoint

        Deletes an Event Endpoint  # noqa: E501
        """
        pass

    def test_get_event_endpoint(self):
        """Test case for get_event_endpoint

        Gets a specific Event Endpoint  # noqa: E501
        """
        pass

    def test_get_event_endpoints(self):
        """Test case for get_event_endpoints

        Gets all Event Endpoints  # noqa: E501
        """
        pass

    def test_reset_secret(self):
        """Test case for reset_secret

        Resets the secret for an Event Endpoint  # noqa: E501
        """
        pass

    def test_update_event_endpoint(self):
        """Test case for update_event_endpoint

        Updates an Event Endpoint  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
