# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.smart_links_api import SmartLinksApi  # noqa: E501
from swagger_client.rest import ApiException


class TestSmartLinksApi(unittest.TestCase):
    """SmartLinksApi unit test stubs"""

    def setUp(self):
        self.api = SmartLinksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_smart_link(self):
        """Test case for add_smart_link

        Creates a Smart Link  # noqa: E501
        """
        pass

    def test_delete_smart_link(self):
        """Test case for delete_smart_link

        Deletes a Smart Link  # noqa: E501
        """
        pass

    def test_get_smart_link1(self):
        """Test case for get_smart_link1

        Gets the details of a specific Smart Link  # noqa: E501
        """
        pass

    def test_get_smart_links(self):
        """Test case for get_smart_links

        Gets all the Smart Links in the org  # noqa: E501
        """
        pass

    def test_update_smart_link(self):
        """Test case for update_smart_link

        Modifies a Smart Link  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
