# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddOrUpdateAutomationFulfillmentModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message': 'str',
        'whisper': 'str',
        'instant_app_schema_api_id': 'str',
        'instant_app_message': 'str',
        'instant_app_parameters': 'str',
        'instant_app_locale': 'str',
        'upload_id': 'int',
        'complete_conversation': 'bool',
        'set_global_opt_out': 'bool',
        'clear_global_opt_out': 'bool',
        'snippet_code': 'str',
        'escalate_groups': 'list[str]',
        'add_to_contact_lists': 'list[str]',
        'remove_from_contact_lists': 'list[str]',
        'remove_from_all_contact_lists': 'bool',
        'add_tags': 'list[str]',
        'remove_tags': 'list[str]',
        'data': 'dict(str, str)'
    }

    attribute_map = {
        'message': 'message',
        'whisper': 'whisper',
        'instant_app_schema_api_id': 'instantAppSchemaApiId',
        'instant_app_message': 'instantAppMessage',
        'instant_app_parameters': 'instantAppParameters',
        'instant_app_locale': 'instantAppLocale',
        'upload_id': 'uploadId',
        'complete_conversation': 'completeConversation',
        'set_global_opt_out': 'setGlobalOptOut',
        'clear_global_opt_out': 'clearGlobalOptOut',
        'snippet_code': 'snippetCode',
        'escalate_groups': 'escalateGroups',
        'add_to_contact_lists': 'addToContactLists',
        'remove_from_contact_lists': 'removeFromContactLists',
        'remove_from_all_contact_lists': 'removeFromAllContactLists',
        'add_tags': 'addTags',
        'remove_tags': 'removeTags',
        'data': 'data'
    }

    def __init__(self, message=None, whisper=None, instant_app_schema_api_id=None, instant_app_message=None, instant_app_parameters=None, instant_app_locale=None, upload_id=None, complete_conversation=None, set_global_opt_out=None, clear_global_opt_out=None, snippet_code=None, escalate_groups=None, add_to_contact_lists=None, remove_from_contact_lists=None, remove_from_all_contact_lists=None, add_tags=None, remove_tags=None, data=None):  # noqa: E501
        """AddOrUpdateAutomationFulfillmentModel - a model defined in Swagger"""  # noqa: E501
        self._message = None
        self._whisper = None
        self._instant_app_schema_api_id = None
        self._instant_app_message = None
        self._instant_app_parameters = None
        self._instant_app_locale = None
        self._upload_id = None
        self._complete_conversation = None
        self._set_global_opt_out = None
        self._clear_global_opt_out = None
        self._snippet_code = None
        self._escalate_groups = None
        self._add_to_contact_lists = None
        self._remove_from_contact_lists = None
        self._remove_from_all_contact_lists = None
        self._add_tags = None
        self._remove_tags = None
        self._data = None
        self.discriminator = None
        if message is not None:
            self.message = message
        if whisper is not None:
            self.whisper = whisper
        if instant_app_schema_api_id is not None:
            self.instant_app_schema_api_id = instant_app_schema_api_id
        if instant_app_message is not None:
            self.instant_app_message = instant_app_message
        if instant_app_parameters is not None:
            self.instant_app_parameters = instant_app_parameters
        if instant_app_locale is not None:
            self.instant_app_locale = instant_app_locale
        if upload_id is not None:
            self.upload_id = upload_id
        if complete_conversation is not None:
            self.complete_conversation = complete_conversation
        if set_global_opt_out is not None:
            self.set_global_opt_out = set_global_opt_out
        if clear_global_opt_out is not None:
            self.clear_global_opt_out = clear_global_opt_out
        if snippet_code is not None:
            self.snippet_code = snippet_code
        if escalate_groups is not None:
            self.escalate_groups = escalate_groups
        if add_to_contact_lists is not None:
            self.add_to_contact_lists = add_to_contact_lists
        if remove_from_contact_lists is not None:
            self.remove_from_contact_lists = remove_from_contact_lists
        if remove_from_all_contact_lists is not None:
            self.remove_from_all_contact_lists = remove_from_all_contact_lists
        if add_tags is not None:
            self.add_tags = add_tags
        if remove_tags is not None:
            self.remove_tags = remove_tags
        if data is not None:
            self.data = data

    @property
    def message(self):
        """Gets the message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        The message to send to the user  # noqa: E501

        :return: The message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this AddOrUpdateAutomationFulfillmentModel.

        The message to send to the user  # noqa: E501

        :param message: The message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def whisper(self):
        """Gets the whisper of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        The message to be posted to the conversation so that only agents can see it  # noqa: E501

        :return: The whisper of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._whisper

    @whisper.setter
    def whisper(self, whisper):
        """Sets the whisper of this AddOrUpdateAutomationFulfillmentModel.

        The message to be posted to the conversation so that only agents can see it  # noqa: E501

        :param whisper: The whisper of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._whisper = whisper

    @property
    def instant_app_schema_api_id(self):
        """Gets the instant_app_schema_api_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        The programmatic, unique id of the schema for this Instant App Schema.  # noqa: E501

        :return: The instant_app_schema_api_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_schema_api_id

    @instant_app_schema_api_id.setter
    def instant_app_schema_api_id(self, instant_app_schema_api_id):
        """Sets the instant_app_schema_api_id of this AddOrUpdateAutomationFulfillmentModel.

        The programmatic, unique id of the schema for this Instant App Schema.  # noqa: E501

        :param instant_app_schema_api_id: The instant_app_schema_api_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._instant_app_schema_api_id = instant_app_schema_api_id

    @property
    def instant_app_message(self):
        """Gets the instant_app_message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :return: The instant_app_message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_message

    @instant_app_message.setter
    def instant_app_message(self, instant_app_message):
        """Sets the instant_app_message of this AddOrUpdateAutomationFulfillmentModel.

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :param instant_app_message: The instant_app_message of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._instant_app_message = instant_app_message

    @property
    def instant_app_parameters(self):
        """Gets the instant_app_parameters of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Instant App parameters passed into the Instant App  # noqa: E501

        :return: The instant_app_parameters of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_parameters

    @instant_app_parameters.setter
    def instant_app_parameters(self, instant_app_parameters):
        """Sets the instant_app_parameters of this AddOrUpdateAutomationFulfillmentModel.

        Instant App parameters passed into the Instant App  # noqa: E501

        :param instant_app_parameters: The instant_app_parameters of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._instant_app_parameters = instant_app_parameters

    @property
    def instant_app_locale(self):
        """Gets the instant_app_locale of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Instant App locale  # noqa: E501

        :return: The instant_app_locale of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_locale

    @instant_app_locale.setter
    def instant_app_locale(self, instant_app_locale):
        """Sets the instant_app_locale of this AddOrUpdateAutomationFulfillmentModel.

        Instant App locale  # noqa: E501

        :param instant_app_locale: The instant_app_locale of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._instant_app_locale = instant_app_locale

    @property
    def upload_id(self):
        """Gets the upload_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Id of the upload to deliver  # noqa: E501

        :return: The upload_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: int
        """
        return self._upload_id

    @upload_id.setter
    def upload_id(self, upload_id):
        """Sets the upload_id of this AddOrUpdateAutomationFulfillmentModel.

        Id of the upload to deliver  # noqa: E501

        :param upload_id: The upload_id of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: int
        """

        self._upload_id = upload_id

    @property
    def complete_conversation(self):
        """Gets the complete_conversation of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Should the conversation be removed from agent's active list  # noqa: E501

        :return: The complete_conversation of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: bool
        """
        return self._complete_conversation

    @complete_conversation.setter
    def complete_conversation(self, complete_conversation):
        """Sets the complete_conversation of this AddOrUpdateAutomationFulfillmentModel.

        Should the conversation be removed from agent's active list  # noqa: E501

        :param complete_conversation: The complete_conversation of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: bool
        """

        self._complete_conversation = complete_conversation

    @property
    def set_global_opt_out(self):
        """Gets the set_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Mark the contact as opted out for all channels  # noqa: E501

        :return: The set_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: bool
        """
        return self._set_global_opt_out

    @set_global_opt_out.setter
    def set_global_opt_out(self, set_global_opt_out):
        """Sets the set_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.

        Mark the contact as opted out for all channels  # noqa: E501

        :param set_global_opt_out: The set_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: bool
        """

        self._set_global_opt_out = set_global_opt_out

    @property
    def clear_global_opt_out(self):
        """Gets the clear_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        Clear the flag marking the contact as opted out for all channels  # noqa: E501

        :return: The clear_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: bool
        """
        return self._clear_global_opt_out

    @clear_global_opt_out.setter
    def clear_global_opt_out(self, clear_global_opt_out):
        """Sets the clear_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.

        Clear the flag marking the contact as opted out for all channels  # noqa: E501

        :param clear_global_opt_out: The clear_global_opt_out of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: bool
        """

        self._clear_global_opt_out = clear_global_opt_out

    @property
    def snippet_code(self):
        """Gets the snippet_code of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501

        JavaScript Snippet to be executed  # noqa: E501

        :return: The snippet_code of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: str
        """
        return self._snippet_code

    @snippet_code.setter
    def snippet_code(self, snippet_code):
        """Sets the snippet_code of this AddOrUpdateAutomationFulfillmentModel.

        JavaScript Snippet to be executed  # noqa: E501

        :param snippet_code: The snippet_code of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: str
        """

        self._snippet_code = snippet_code

    @property
    def escalate_groups(self):
        """Gets the escalate_groups of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The escalate_groups of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._escalate_groups

    @escalate_groups.setter
    def escalate_groups(self, escalate_groups):
        """Sets the escalate_groups of this AddOrUpdateAutomationFulfillmentModel.


        :param escalate_groups: The escalate_groups of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: list[str]
        """

        self._escalate_groups = escalate_groups

    @property
    def add_to_contact_lists(self):
        """Gets the add_to_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The add_to_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._add_to_contact_lists

    @add_to_contact_lists.setter
    def add_to_contact_lists(self, add_to_contact_lists):
        """Sets the add_to_contact_lists of this AddOrUpdateAutomationFulfillmentModel.


        :param add_to_contact_lists: The add_to_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: list[str]
        """

        self._add_to_contact_lists = add_to_contact_lists

    @property
    def remove_from_contact_lists(self):
        """Gets the remove_from_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The remove_from_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._remove_from_contact_lists

    @remove_from_contact_lists.setter
    def remove_from_contact_lists(self, remove_from_contact_lists):
        """Sets the remove_from_contact_lists of this AddOrUpdateAutomationFulfillmentModel.


        :param remove_from_contact_lists: The remove_from_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: list[str]
        """

        self._remove_from_contact_lists = remove_from_contact_lists

    @property
    def remove_from_all_contact_lists(self):
        """Gets the remove_from_all_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The remove_from_all_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: bool
        """
        return self._remove_from_all_contact_lists

    @remove_from_all_contact_lists.setter
    def remove_from_all_contact_lists(self, remove_from_all_contact_lists):
        """Sets the remove_from_all_contact_lists of this AddOrUpdateAutomationFulfillmentModel.


        :param remove_from_all_contact_lists: The remove_from_all_contact_lists of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: bool
        """

        self._remove_from_all_contact_lists = remove_from_all_contact_lists

    @property
    def add_tags(self):
        """Gets the add_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The add_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._add_tags

    @add_tags.setter
    def add_tags(self, add_tags):
        """Sets the add_tags of this AddOrUpdateAutomationFulfillmentModel.


        :param add_tags: The add_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: list[str]
        """

        self._add_tags = add_tags

    @property
    def remove_tags(self):
        """Gets the remove_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The remove_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: list[str]
        """
        return self._remove_tags

    @remove_tags.setter
    def remove_tags(self, remove_tags):
        """Sets the remove_tags of this AddOrUpdateAutomationFulfillmentModel.


        :param remove_tags: The remove_tags of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: list[str]
        """

        self._remove_tags = remove_tags

    @property
    def data(self):
        """Gets the data of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501


        :return: The data of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this AddOrUpdateAutomationFulfillmentModel.


        :param data: The data of this AddOrUpdateAutomationFulfillmentModel.  # noqa: E501
        :type: dict(str, str)
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddOrUpdateAutomationFulfillmentModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddOrUpdateAutomationFulfillmentModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
