# coding: utf-8

"""
    Prompt.io APIs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddScheduledActionModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'int',
        'org_channel_id': 'str',
        'customer_channel_id': 'str',
        'message': 'str',
        'whisper': 'str',
        'instant_app_schema_id': 'str',
        'instant_app_message': 'str',
        'instant_app_parameters': 'str',
        'instant_app_locale': 'str',
        'upload_id': 'int',
        'deliver_on': 'int',
        'topic': 'str'
    }

    attribute_map = {
        'user_id': 'userId',
        'org_channel_id': 'orgChannelId',
        'customer_channel_id': 'customerChannelId',
        'message': 'message',
        'whisper': 'whisper',
        'instant_app_schema_id': 'instantAppSchemaID',
        'instant_app_message': 'instantAppMessage',
        'instant_app_parameters': 'instantAppParameters',
        'instant_app_locale': 'instantAppLocale',
        'upload_id': 'uploadId',
        'deliver_on': 'deliverOn',
        'topic': 'topic'
    }

    def __init__(self, user_id=None, org_channel_id=None, customer_channel_id=None, message=None, whisper=None, instant_app_schema_id=None, instant_app_message=None, instant_app_parameters=None, instant_app_locale=None, upload_id=None, deliver_on=None, topic=None):  # noqa: E501
        """AddScheduledActionModel - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._org_channel_id = None
        self._customer_channel_id = None
        self._message = None
        self._whisper = None
        self._instant_app_schema_id = None
        self._instant_app_message = None
        self._instant_app_parameters = None
        self._instant_app_locale = None
        self._upload_id = None
        self._deliver_on = None
        self._topic = None
        self.discriminator = None
        if user_id is not None:
            self.user_id = user_id
        self.org_channel_id = org_channel_id
        if customer_channel_id is not None:
            self.customer_channel_id = customer_channel_id
        if message is not None:
            self.message = message
        if whisper is not None:
            self.whisper = whisper
        if instant_app_schema_id is not None:
            self.instant_app_schema_id = instant_app_schema_id
        if instant_app_message is not None:
            self.instant_app_message = instant_app_message
        if instant_app_parameters is not None:
            self.instant_app_parameters = instant_app_parameters
        if instant_app_locale is not None:
            self.instant_app_locale = instant_app_locale
        if upload_id is not None:
            self.upload_id = upload_id
        if deliver_on is not None:
            self.deliver_on = deliver_on
        if topic is not None:
            self.topic = topic

    @property
    def user_id(self):
        """Gets the user_id of this AddScheduledActionModel.  # noqa: E501

        ID of the team member that will deliver the Scheduled Action.  # noqa: E501

        :return: The user_id of this AddScheduledActionModel.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AddScheduledActionModel.

        ID of the team member that will deliver the Scheduled Action.  # noqa: E501

        :param user_id: The user_id of this AddScheduledActionModel.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def org_channel_id(self):
        """Gets the org_channel_id of this AddScheduledActionModel.  # noqa: E501

        The org channel apiId (or internal id) of the sending channel for message and Instant App actions  # noqa: E501

        :return: The org_channel_id of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._org_channel_id

    @org_channel_id.setter
    def org_channel_id(self, org_channel_id):
        """Sets the org_channel_id of this AddScheduledActionModel.

        The org channel apiId (or internal id) of the sending channel for message and Instant App actions  # noqa: E501

        :param org_channel_id: The org_channel_id of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """
        if org_channel_id is None:
            raise ValueError("Invalid value for `org_channel_id`, must not be `None`")  # noqa: E501

        self._org_channel_id = org_channel_id

    @property
    def customer_channel_id(self):
        """Gets the customer_channel_id of this AddScheduledActionModel.  # noqa: E501

        The customer channel apiId (or internal id) that will receive the message or Instant App actions.  # noqa: E501

        :return: The customer_channel_id of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._customer_channel_id

    @customer_channel_id.setter
    def customer_channel_id(self, customer_channel_id):
        """Sets the customer_channel_id of this AddScheduledActionModel.

        The customer channel apiId (or internal id) that will receive the message or Instant App actions.  # noqa: E501

        :param customer_channel_id: The customer_channel_id of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._customer_channel_id = customer_channel_id

    @property
    def message(self):
        """Gets the message of this AddScheduledActionModel.  # noqa: E501

        The message to send to the user  # noqa: E501

        :return: The message of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this AddScheduledActionModel.

        The message to send to the user  # noqa: E501

        :param message: The message of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def whisper(self):
        """Gets the whisper of this AddScheduledActionModel.  # noqa: E501

        The message to be posted to the conversation so that only agents can see it  # noqa: E501

        :return: The whisper of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._whisper

    @whisper.setter
    def whisper(self, whisper):
        """Sets the whisper of this AddScheduledActionModel.

        The message to be posted to the conversation so that only agents can see it  # noqa: E501

        :param whisper: The whisper of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._whisper = whisper

    @property
    def instant_app_schema_id(self):
        """Gets the instant_app_schema_id of this AddScheduledActionModel.  # noqa: E501

        Optional schema apiId (or internal id) used to create an instance of an Instant App.  # noqa: E501

        :return: The instant_app_schema_id of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_schema_id

    @instant_app_schema_id.setter
    def instant_app_schema_id(self, instant_app_schema_id):
        """Sets the instant_app_schema_id of this AddScheduledActionModel.

        Optional schema apiId (or internal id) used to create an instance of an Instant App.  # noqa: E501

        :param instant_app_schema_id: The instant_app_schema_id of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_schema_id = instant_app_schema_id

    @property
    def instant_app_message(self):
        """Gets the instant_app_message of this AddScheduledActionModel.  # noqa: E501

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :return: The instant_app_message of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_message

    @instant_app_message.setter
    def instant_app_message(self, instant_app_message):
        """Sets the instant_app_message of this AddScheduledActionModel.

        Invite message to send for the Instant App. The customer link will replace the {link} token or will be placed at the end of the message  # noqa: E501

        :param instant_app_message: The instant_app_message of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_message = instant_app_message

    @property
    def instant_app_parameters(self):
        """Gets the instant_app_parameters of this AddScheduledActionModel.  # noqa: E501

        Optional Instant App parameters passed into the Instant App  # noqa: E501

        :return: The instant_app_parameters of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_parameters

    @instant_app_parameters.setter
    def instant_app_parameters(self, instant_app_parameters):
        """Sets the instant_app_parameters of this AddScheduledActionModel.

        Optional Instant App parameters passed into the Instant App  # noqa: E501

        :param instant_app_parameters: The instant_app_parameters of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_parameters = instant_app_parameters

    @property
    def instant_app_locale(self):
        """Gets the instant_app_locale of this AddScheduledActionModel.  # noqa: E501

        Optional locale for the Instant App  # noqa: E501

        :return: The instant_app_locale of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._instant_app_locale

    @instant_app_locale.setter
    def instant_app_locale(self, instant_app_locale):
        """Sets the instant_app_locale of this AddScheduledActionModel.

        Optional locale for the Instant App  # noqa: E501

        :param instant_app_locale: The instant_app_locale of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._instant_app_locale = instant_app_locale

    @property
    def upload_id(self):
        """Gets the upload_id of this AddScheduledActionModel.  # noqa: E501


        :return: The upload_id of this AddScheduledActionModel.  # noqa: E501
        :rtype: int
        """
        return self._upload_id

    @upload_id.setter
    def upload_id(self, upload_id):
        """Sets the upload_id of this AddScheduledActionModel.


        :param upload_id: The upload_id of this AddScheduledActionModel.  # noqa: E501
        :type: int
        """

        self._upload_id = upload_id

    @property
    def deliver_on(self):
        """Gets the deliver_on of this AddScheduledActionModel.  # noqa: E501

        The UTC timestamp the Scheduled Action will be delivered.  # noqa: E501

        :return: The deliver_on of this AddScheduledActionModel.  # noqa: E501
        :rtype: int
        """
        return self._deliver_on

    @deliver_on.setter
    def deliver_on(self, deliver_on):
        """Sets the deliver_on of this AddScheduledActionModel.

        The UTC timestamp the Scheduled Action will be delivered.  # noqa: E501

        :param deliver_on: The deliver_on of this AddScheduledActionModel.  # noqa: E501
        :type: int
        """

        self._deliver_on = deliver_on

    @property
    def topic(self):
        """Gets the topic of this AddScheduledActionModel.  # noqa: E501

        Topic for the customer conversation.  # noqa: E501

        :return: The topic of this AddScheduledActionModel.  # noqa: E501
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """Sets the topic of this AddScheduledActionModel.

        Topic for the customer conversation.  # noqa: E501

        :param topic: The topic of this AddScheduledActionModel.  # noqa: E501
        :type: str
        """

        self._topic = topic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddScheduledActionModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddScheduledActionModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
